#!/bin/sh
# Copyright IBM Corp. 2003

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Configuration Based Update Installer
#----------------------------------------------------------------------------------

# set DEBUG_UPDATE=yes to turn on debugging statements
DEBUG_UPDATE=

MotifLAF=com.sun.java.swing.plaf.motif.MotifLookAndFeel

success_rc=0
fail_rc=$?

LaunchTitle=$0

runInstaller=
launchInstaller=
useLocalJDK=
prepareJDK=
useJavaHome=
checkSetup=
callSetup=
checkClientSetup=
callClientSetup=
failSetup=
testJDK=
copyJDK=
failedCopyJDK=
okCopyJDK=

currentDir=`dirname $0`        

PREREQ_DISABLE_INST=
PREREQ_DISABLE_UNINST=
FOR_EFIX=
RUN_JAVA_HOME=
WP_PUI_CONFIG=


#----------------------------------------------------------------------------------
#  Initialization and setup
#----------------------------------------------------------------------------------
echo Start of [ "$LaunchTitle" ]
echo Build 20070718_0131
echo

echo Verifying installer jar:
echo   [ PortalUpdateInstaller.jar ]
echo
if [ -f "$currentDir"/PortalUpdateInstaller.jar ] 
   then        
   
   
      while [ "$1" ]
      	   do 	   		
      	      if [ "$1" = "-dpInstall" ]
      	 	 then 
      		      PREREQ_DISABLE_INST="-W EfixInstallPrereqErrorAction.prereqOverride=yes"
      	      elif [ "$1" = "-dpUninstall" ] 
      		 then
      		      PREREQ_DISABLE_UNINST="-W EfixUninstallPrereqError.prereqOverride=yes"
      	      elif [ "$1" = "-efixOnly" ] 
      	         then
      	              FOR_EFIX="-W UpdateActionSelect.disablePTFOptions=yes"
      	      elif [ "$1" = "-configProperties" ] 
      	         then
                      WP_PUI_CONFIG=$2
      	              shift 
      	      elif [ "$1" = "-usage" ] 
      	         then
      	              echo
      	              echo Usage: updateWizard [ -efixOnly ] [ -dpInstall ] [ -dpUninstall ] [ -configProperties cfgFile ] [ -usage ]
      		      echo
      		      echo   efixOnly         - Run the installer in EFix Processing mode only. 
      		      echo   dpInstall        - Disable install prerequisite error locking.	
      		      echo   dpUninstall      - Disable uninstall prerequisite error locking.
      		      echo   configProperties - Additional configuration properties to be passed to FixPak/fix processing.
      		      echo   usage            - Display syntax help. 
      		      echo       	
      		      exit $fail_rc            	           	  		  
      		 else 
      		      echo Usage error: [ "$1" is an unrecognized argument ]	          	          	          
      		      exit $fail_rc
      	      fi	     	       	     
      	      
      	      shift	      
      done

        if [ "$WAS_HOME" ] 
        then 
            if [ -f "$WAS_HOME"/bin/setupCmdLine.sh ]
            then
                echo Attempting to locate setupCmdLine.sh
                echo
                callSetup=1
            else
                failSetup=1
            fi
        else
            echo The WAS_HOME env variable MUST be set.  
            echo Exiting.
            echo
            exit $fail_rc
        fi
else
    echo "The installer jar (PortalUpdateInstaller) file does not exist."
    echo Exiting.
    echo
    exit $fail_rc
fi     
  
if [ "$failSetup" ]
   then        
	echo Unable to locate setupCmdLine.sh, this is usually located beneath your
	echo WebSphere AppServer installation, in the 'bin' directory
	echo
	echo Exiting.	
	echo
	exit $fail_rc 
fi

if [ "$callSetup" ]
   then                  
        . $WAS_HOME/bin/setupCmdLine.sh
        testJDK=1
fi

if [ "$testJDK" ]
   then
        if [ -f "$JAVA_HOME"/bin/java ]
           then
                launchInstaller=1
           else
                echo The JDK was not found within the set JAVA_HOME:
        	echo     JAVA_HOME: [ "$JAVA_HOME"/bin/java ]
        	echo
        	echo Exiting.
        	echo
        	exit $fail_rc
        fi           
fi  
      
PLATFORM=`uname`
export PLATFORM
                 
	                   
#----------------------------------------------------------------------------------
# Set up library loading for native extfile libs
#----------------------------------------------------------------------------------

# Cases for platform specific goop.
case ${PLATFORM} in
        Linux)
                # Select the right arch library for the utils!
                OS_ARCH=`uname -m`
                case ${OS_ARCH} in
                    i386|i486|i586|i686|i786|i886|athlon)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/bin/ia32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    ppc|ppc64)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/bin/ppc32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    s390|s390x)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/bin/s390:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    *)    
                        echo "Unknown Linux Architechture: ${OS_ARCH}. Native file libraries will not be loaded."
                        ;;
                esac
                ;;
        SunOS|Solaris)
                LD_LIBRARY_PATH=${currentDir}/lib/solaris/bin/sparc:${LD_LIBRARY_PATH}
                export LD_LIBRARY_PATH
                ;;
        HP-UX)
                SHLIB_PATH=${currentDir}/lib/hpux/bin/pa-risc:${SHLIB_PATH}
                export SHLIB_PATH
                
                # Make sure this is executable or it won't load!
                if [ ! -x ${currentDir}/lib/hpux/bin/pa-risc/libNativeFile.sl ] ; then
                    chmod 755 ${currentDir}/lib/hpux/bin/pa-risc/libNativeFile.sl
                    chmod_rc=$?
                       if [ 0 -ne ${chmod_rc} ]
                          then
                          echo Could not set execute permissions on ${currentDir}/lib/hpux/bin/pa-risc/libNativeFile.sl
                          echo Make sure that this file has execute permission and run again
                          exit ${chmod_rc}
                       fi
                fi                 
                ;;
        AIX)    
                # Discern between 32 and 64 bit processor
                AIX_PROCESSOR=`bootinfo -K`
                case ${AIX_PROCESSOR} in
                    32)
                        LIBPATH=${currentDir}/lib/aix/bin/ppc32:${LIBPATH}
                        export LIBPATH
                        ;;
                    64)
                        LIBPATH=${currentDir}/lib/aix/bin/ppc64:${LIBPATH}
                        export LIBPATH
                        ;;
                esac
                export LIBPATH
                ;;
        OS400)
        	;;
        *)
                echo "Unknown platform: ${PLATFORM}.  Native file libraries will not be loaded."
                ;;
esac


#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------

    
#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------
#DBG_PROP="-Dcom.ibm.websphere.update.ptf.log.level=5 -Dcom.ibm.websphere.update.delta.earutils.debug=false -Dcom.ibm.websphere.update.ioservices.debug=false -Dcom.ibm.websphere.update.delta.debug=true -Dcom.ibm.websphere.update.efix.prereq.debug=true -Dcom.ibm.websphere.update.harness.debug=true -Dcom.ibm.websphere.update.launch.debug=true -Dcom.ibm.websphere.update.ptf.debug=true -Dcom.ibm.websphere.update.ptf.prereq.debug=true -Dcom.ibm.websphere.update.transforms.debug=true -Dcom.ibm.websphere.update.util.debug=true -Dcom.ibm.websphere.update.delta.warutils.debug=true -Dcom.ibm.ws.update.debug=true"
#export DBG_PROP

if [ "$launchInstaller" ] 
  then                               
       if [ "$FOR_EFIX" ]
          then
               if [ "$PREREQ_DISABLE_INST" ]
                  then
                       if [ "$PREREQ_DISABLE_UNINST" ]
                          then        
                               runInstaller=1        
                               skip=1
                               "$JAVA_HOME"/bin/java \
                               -Xmx512m \
 	                       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	                       -Dswing.defaultlaf="$MotifLAF" \
                           -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                           -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       -DCURRENT_UPDATE_DIR="${currentDir}" \
                                ${DBG_PROP} \
  	                       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx512m \
 	                       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
                           -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
  	                       -Dswing.defaultlaf="$MotifLAF" \
  	                       -DCURRENT_UPDATE_DIR="${currentDir}" \
                                ${DBG_PROP} \
    	                       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_INST"`    	                    
  	               fi
  	        fi 
  	        
  	        if [ "$PREREQ_DISABLE_UNINST" ]
                  then
                       if [ "$PREREQ_DISABLE_INST" ]
                          then   
			       if [ "$skip" ]                          
                                  then 
                                       echo
                                  else
                               	       runInstaller=1             
                               	       "$JAVA_HOME"/bin/java \
                               	       -Xmx512m \
 	                       	       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
                                   -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                                   -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       	       -Dswing.defaultlaf="$MotifLAF" \
  	                               -DCURRENT_UPDATE_DIR="${currentDir}" \
                                        ${DBG_PROP} \
  	                       	       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                       fi
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx512m \
 	                       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
                           -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                           -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       -Dswing.defaultlaf="$MotifLAF" \
  	                       -DCURRENT_UPDATE_DIR="${currentDir}" \
                                ${DBG_PROP} \
    	                       run `echo "$FOR_EFIX"` `echo "$PREREQ_DISABLE_UNINST"`    	                    
  	               fi
  	        fi 
  	        
  	        if [ "$runInstaller" ]
  	           then
  	           	echo
  	           else  	                
  	                runInstaller=1    
  	                
                	"$JAVA_HOME"/bin/java \
                	-Xmx512m \
 	        	-cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
                -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	        	-Dswing.defaultlaf="$MotifLAF" \
  	        	-DCURRENT_UPDATE_DIR="${currentDir}" \
                         ${DBG_PROP} \
  	        	run `echo "$FOR_EFIX"`
  	        fi    
  	   else  	   
  	   	if [ "$PREREQ_DISABLE_INST" ]
                   then
                        if [ "$PREREQ_DISABLE_UNINST" ]
                           then        
                               skip=1
                               runInstaller=1        
                               "$JAVA_HOME"/bin/java \
                               -Xmx512m \
 	                       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	                       -Dswing.defaultlaf="$MotifLAF" \
                           -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                           -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       -DCURRENT_UPDATE_DIR="${currentDir}" \
                                ${DBG_PROP} \
  	                       run `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx512m \
 	                       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	                       -Dswing.defaultlaf="$MotifLAF" \
                           -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                           -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       -DCURRENT_UPDATE_DIR="${currentDir}" \
                                ${DBG_PROP} \
    	                       run `echo "$PREREQ_DISABLE_INST"`    	                    
  	                fi
  	        fi 
  	        
  	        if [ "$PREREQ_DISABLE_UNINST" ]
                   then
                       if [ "$PREREQ_DISABLE_INST" ]
                          then   
                               if [ "$skip" ]
                                  then
                                        echo
                                  else
                               		runInstaller=1             
                               		"$JAVA_HOME"/bin/java \
                               		-Xmx512m \
 	                       		-cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	                       		-Dswing.defaultlaf="$MotifLAF" \
                                -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                                -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       		-DCURRENT_UPDATE_DIR="${currentDir}" \
                                         ${DBG_PROP} \
  	                       		run `echo "$PREREQ_DISABLE_INST"` `echo "$PREREQ_DISABLE_UNINST"`
  	                       fi
  	                  else  
  	                       runInstaller=1	             
                               "$JAVA_HOME"/bin/java \
                               -Xmx512m \
 	                       -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	                       -Dswing.defaultlaf="$MotifLAF" \
                           -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
                           -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	                       -DCURRENT_UPDATE_DIR="${currentDir}" \
                                ${DBG_PROP} \
    	                       run `echo "$PREREQ_DISABLE_UNINST"`    	                    
  	               fi
  	        fi   	          	       	   
        fi
  	
  	if [ "$runInstaller" ] 
  	   then echo 
  	   else  	     
  	     echo "$JAVA_HOME"/bin/java \
  	     -Xmx512m \
 	     -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	     -Dswing.defaultlaf="$MotifLAF" \
         -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
         -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	     -DCURRENT_UPDATE_DIR="${currentDir}" \
              ${DBG_PROP} \
  	     run
         
  	     "$JAVA_HOME"/bin/java \
  	     -Xmx512m \
 	     -cp "$currentDir"/PortalUpdateInstaller.jar:"$currentDir"/lib/nativefile.jar \
  	     -Dswing.defaultlaf="$MotifLAF" \
         -Dcom.ibm.wps.pui.configprops="$WP_PUI_CONFIG" \
         -Dcom.ibm.wp.pui.bld.level=20070718_0131 \
  	     -DCURRENT_UPDATE_DIR="${currentDir}" \
              ${DBG_PROP} \
  	     run
  	fi
  	                    	    
fi

    
echo End of [ "$LaunchTitle" ]
echo 
exit $success_rc
